@@ -438,7 +438,7 @@ class nvdbVegnett:
                             contactsfile,  '\n',   
                     '\n{ "X-Client" : "YOUR SYSTEM",\n', 
                     '"X-Kontaktperson" : "ola.nordmann@eposten.din" }\n' ))
-            warn( mytext ) 
+            # warn( mytext ) 
 
     def miljo(self, *args):
         """Kun internt på vegvesen-nettet!
